==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetCampaignRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCampaignRequest(
    applicationId: __string,
    campaignId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest = {
    import GetCampaignRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .campaignId(__string.unwrap(campaignId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignRequest.wrap(buildAwsValue())
}
object GetCampaignRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignRequest =
      zio.aws.pinpoint.model.GetCampaignRequest(applicationId, campaignId)
    def applicationId: __string
    def campaignId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getCampaignId: ZIO[Any, Nothing, __string] = ZIO.succeed(campaignId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
  ) extends zio.aws.pinpoint.model.GetCampaignRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val campaignId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.campaignId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
  ): zio.aws.pinpoint.model.GetCampaignRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetCampaignRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCampaignRequest(
    applicationId: __string,
    campaignId: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest = {
    import GetCampaignRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .campaignId(campaignId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignRequest.wrap(buildAwsValue())
}
object GetCampaignRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignRequest =
      zio.aws.pinpoint.model.GetCampaignRequest(applicationId, campaignId)
    def applicationId: __string
    def campaignId: __string
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getCampaignId: ZIO[Any, Nothing, __string] = ZIO.succeed(campaignId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
  ) extends zio.aws.pinpoint.model.GetCampaignRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val campaignId: __string = impl.campaignId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignRequest
  ): zio.aws.pinpoint.model.GetCampaignRequest.ReadOnly = new Wrapper(impl)
}
